==> nextcloud-25.0.11.tgz: nextcloud/apps/systemtags/l10n/ar.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "إسم الوسم فارغ",
    "Update" : "تحديث",
    "Create" : "إنشاء",
    "Select tag …" : "إختر وسما…",
    "System tag %1$s added by the system" : "الوسم النظامي %1$s تمت إضافته من النظام",
    "Added system tag {systemtag}" : "وسم نظامي مضاف {systemtag}",
    "Added system tag %1$s" : "وسم نظامي مضاف %1$s",
    "%1$s added system tag %2$s" : "%1$s أضاف الوسم النظامي%2$s",
    "{actor} added system tag {systemtag}" : "{actor} أضاف الوسم النظامي {systemtag}",
    "System tag %1$s removed by the system" : " وسم نظامي %1$s تمّ حذفه من النظام",
    "Removed system tag {systemtag}" : "وسم نظامي محذوف {systemtag}",
    "Removed system tag %1$s" : "وسم نظامي محذوف %1$s",
    "%1$s removed system tag %2$s" : "%1$s حذف الوسم النظامي %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} حذف الوسم النظامي {systemtag}",
    "You created system tag %1$s" : "أنت أنشأت الوسم النظامي %1$s",
    "You created system tag {systemtag}" : "أنت أنشأت الوسم النظامي {systemtag}",
    "%1$s created system tag %2$s" : "%1$s أنشأ الوسم النظامي %2$s",
    "{actor} created system tag {systemtag}" : "{actor} أنشأ الوسم النظامي {systemtag}",
    "You deleted system tag %1$s" : "أنت حذفت الوسم النظامي %1$s",
    "You deleted system tag {systemtag}" : "أنت حذفت الوسم النظامي {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s حذف الوسم النظامي %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} حذف الوسم النظامي {systemtag}",
    "You updated system tag %2$s to %1$s" : "أنت غيّرت الوسم النظامي %2$s إلى %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "أنت عدّلت الوسم النظامي {oldsystemtag} إلى {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s عدّل الوسم النظامي %3$s إلى %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} عدّل الوسم النظامي {oldsystemtag}  إلى {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "الوسم النظامي %2$s تمّت إضافته إلى %1$s من قِبل النظام",
    "System tag {systemtag} was added to {file} by the system" : "الوسم النظامي {systemtag} تمّت إضافته إلى {file} من قِبل النظام",
    "You added system tag %2$s to %1$s" : "أنت قمت بإضافة الوسم النظامي %2$s إلى %1$s",
    "You added system tag {systemtag} to {file}" : "أنت قمت بإضافة الوسم النظامي {systemtag}  إلى {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s أضاف الوسم النظامي %3$s إلى %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} أضاف الوسم النظامي {systemtag} إلى {file}",
    "System tag %2$s was removed from %1$s by the system" : "الوسم النظامي %2$s تمّ حذفه من %1$s من قِبل النظام",
    "System tag {systemtag} was removed from {file} by the system" : "الوسم النظامي {systemtag} تمّ حذفه من {file} من قِبل النظام",
    "You removed system tag %2$s from %1$s" : "أنت حذفت الوسم النظامي %2$s من %1$s",
    "You removed system tag {systemtag} from {file}" : "أنت حذفت الوسم النظامي {systemtag} من {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s حذف الوسم النظامي %3$s من %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} حذف الوسم النظامي {systemtag} من {file}",
    "%s (restricted)" : "%s (محظور)",
    "%s (invisible)" : "%s (مخفي)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>وسم النظام</strong> للملف تمّ تغييرها",
    "Tags" : "الوسوم",
    "All tagged %s …" : "جميع الوسوم %s …",
    "tagged %s" : "موسوم %s",
    "Collaborative tags" : "وسوم التعاونية",
    "Collaborative tagging functionality which shares tags among users." : "وظيفة التوسيم التعاوني التي تسمح بمشاركة الوسوم tags فيما بين المستخدمين.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "وظيفة التوسيم التعاوني التي تسمح بمشاركة الوسوم tags فيما بين المستخدمين. ذات فائدة عظيمة لعمل الفرق.\n\t(إذا كنت مستضيفاً لنظام متعدد المستأجرين multi-tenant، فإنه يُنصح بأن تقوم بتعطيل هذه الخدمة حيث أن الوسوم ستتم مشاركتها بين جميع المستخدمين من جميع المستأجرين.)",
    "Loading collaborative tags …" : "تحميل الوسوم التعاونية ...",
    "Search or create collaborative tags" : "البحث عن أو إنشاء وسم تعاوني",
    "Collaborative tags …" : "وسوم تعاونية ...",
    "No tags to select, type to create a new tag" : "لا توجد أي وسوم؛ أكتب لإنشاء وسم جديد",
    "Failed to load tags" : "إخفاق في تحميل الوسوم",
    "Failed to load selected tags" : "إخفاق في تحميل الوسوم المنتقاة",
    "Failed to select tag" : "إخفاق في اختيار وسم",
    "Failed to create tag" : "إخفاق في إنشا وسم",
    "Failed to delete tag" : "إخفاق في حذف وسم",
    "This file has the tag {tag}" : "هذا الملف له واصفة {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "هذا الملف له واصفات {firstTags} و {lastTag}",
    "Failed to load last used tags" : "إخفاق في تحميل آخر الوسوم استعمالاً",
    "Missing \"Content-Location\" header" : "ترويسة موقع المحتوى  \"Content-Location\" مفقودة",
    "Tagged files" : "الملفات الموسومة",
    "Select tags to filter by" : "حدد الوسوم للترشيح بواسطتها",
    "No tags found" : "لم يُعثَر على أي وسم",
    "Please select tags to filter by" : "الرجاء تحديد الوسوم لترشيح بواسطتها",
    "No files found for the selected tags" : "لم يتم العثور على ملفات مع الوسوم المختارة",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "الوسوم التعاونية مُتاحة لكل المستخدمين. الوسوم المُقيّدة restricted يمكن للمستخدمين رؤيتها لكن لا يمكنهم اسنادها. الوسوم المخفية invisible للاستعمال الداخلي فقط حيث لا يستطيع المستخدمون رؤيتها و لا إسنادها.",
    "Create a new tag" : "أنشئ وسما جديدا",
    "Name" : "اسم",
    "Public" : "للعامة",
    "Restricted" : "مقيدة",
    "Invisible" : "غير مرئية",
    "Delete" : "حذف ",
    "Reset" : "إعادة الضبط",
    "No files in here" : "لا يوجد ملفات هنا ",
    "No entries found in this folder" : "لا يوجد مدخلات في هذا المجلد ",
    "Size" : "حجم",
    "Modified" : "معدل"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-25.0.12.tgz: nextcloud/apps/systemtags/l10n/ar.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "إسم الوسم فارغ",
    "Update" : "تحديث",
    "Create" : "إنشاء",
    "Select tag …" : "إختر وسما…",
    "System tag %1$s added by the system" : "الوسم النظامي %1$s تمت إضافته من النظام",
    "Added system tag {systemtag}" : "وسم نظامي مضاف {systemtag}",
    "Added system tag %1$s" : "وسم نظامي مضاف %1$s",
    "%1$s added system tag %2$s" : "%1$s أضاف الوسم النظامي%2$s",
    "{actor} added system tag {systemtag}" : "{actor} أضاف الوسم النظامي {systemtag}",
    "System tag %1$s removed by the system" : " وسم نظامي %1$s تمّ حذفه من النظام",
    "Removed system tag {systemtag}" : "وسم نظامي محذوف {systemtag}",
    "Removed system tag %1$s" : "وسم نظامي محذوف %1$s",
    "%1$s removed system tag %2$s" : "%1$s حذف الوسم النظامي %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} حذف الوسم النظامي {systemtag}",
    "You created system tag %1$s" : "أنت أنشأت الوسم النظامي %1$s",
    "You created system tag {systemtag}" : "أنت أنشأت الوسم النظامي {systemtag}",
    "%1$s created system tag %2$s" : "%1$s أنشأ الوسم النظامي %2$s",
    "{actor} created system tag {systemtag}" : "{actor} أنشأ الوسم النظامي {systemtag}",
    "You deleted system tag %1$s" : "أنت حذفت الوسم النظامي %1$s",
    "You deleted system tag {systemtag}" : "أنت حذفت الوسم النظامي {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s حذف الوسم النظامي %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} حذف الوسم النظامي {systemtag}",
    "You updated system tag %2$s to %1$s" : "أنت غيّرت الوسم النظامي %2$s إلى %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "أنت عدّلت الوسم النظامي {oldsystemtag} إلى {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s عدّل الوسم النظامي %3$s إلى %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} عدّل الوسم النظامي {oldsystemtag}  إلى {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "الوسم النظامي %2$s تمّت إضافته إلى %1$s من قِبل النظام",
    "System tag {systemtag} was added to {file} by the system" : "الوسم النظامي {systemtag} تمّت إضافته إلى {file} من قِبل النظام",
    "You added system tag %2$s to %1$s" : "أنت قمت بإضافة الوسم النظامي %2$s إلى %1$s",
    "You added system tag {systemtag} to {file}" : "أنت قمت بإضافة الوسم النظامي {systemtag}  إلى {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s أضاف الوسم النظامي %3$s إلى %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} أضاف الوسم النظامي {systemtag} إلى {file}",
    "System tag %2$s was removed from %1$s by the system" : "الوسم النظامي %2$s تمّ حذفه من %1$s من قِبل النظام",
    "System tag {systemtag} was removed from {file} by the system" : "الوسم النظامي {systemtag} تمّ حذفه من {file} من قِبل النظام",
    "You removed system tag %2$s from %1$s" : "أنت حذفت الوسم النظامي %2$s من %1$s",
    "You removed system tag {systemtag} from {file}" : "أنت حذفت الوسم النظامي {systemtag} من {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s حذف الوسم النظامي %3$s من %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} حذف الوسم النظامي {systemtag} من {file}",
    "%s (restricted)" : "%s (محظور)",
    "%s (invisible)" : "%s (مخفي)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>وسم النظام</strong> للملف تمّ تغييرها",
    "Tags" : "الوسوم",
    "All tagged %s …" : "جميع الوسوم %s …",
    "tagged %s" : "موسوم %s",
    "Collaborative tags" : "وسوم التعاونية",
    "Collaborative tagging functionality which shares tags among users." : "وظيفة التوسيم التعاوني التي تسمح بمشاركة الوسوم tags فيما بين المستخدمين.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "وظيفة التوسيم التعاوني التي تسمح بمشاركة الوسوم tags فيما بين المستخدمين. ذات فائدة عظيمة لعمل الفرق.\n\t(إذا كنت مستضيفاً لنظام متعدد المستأجرين multi-tenant، فإنه يُنصح بأن تقوم بتعطيل هذه الخدمة حيث أن الوسوم ستتم مشاركتها بين جميع المستخدمين من جميع المستأجرين.)",
    "Loading collaborative tags …" : "تحميل الوسوم التعاونية ...",
    "Search or create collaborative tags" : "البحث عن أو إنشاء وسم تعاوني",
    "Collaborative tags …" : "وسوم تعاونية ...",
    "No tags to select, type to create a new tag" : "لا توجد أي وسوم؛ أكتب لإنشاء وسم جديد",
    "Failed to load tags" : "إخفاق في تحميل الوسوم",
    "Failed to load selected tags" : "إخفاق في تحميل الوسوم المنتقاة",
    "Failed to select tag" : "إخفاق في اختيار وسم",
    "Failed to create tag" : "إخفاق في إنشا وسم",
    "Failed to delete tag" : "إخفاق في حذف وسم",
    "This file has the tag {tag}" : "هذا الملف له واصفة {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "هذا الملف له واصفات {firstTags} و {lastTag}",
    "No tags found" : "لم يُعثَر على أي وسم",
    "Failed to load last used tags" : "إخفاق في تحميل آخر الوسوم استعمالاً",
    "Missing \"Content-Location\" header" : "ترويسة موقع المحتوى  \"Content-Location\" مفقودة",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "الوسوم التعاونية مُتاحة لكل المستخدمين. الوسوم المُقيّدة restricted يمكن للمستخدمين رؤيتها لكن لا يمكنهم اسنادها. الوسوم المخفية invisible للاستعمال الداخلي فقط حيث لا يستطيع المستخدمون رؤيتها و لا إسنادها.",
    "Create a new tag" : "أنشئ وسما جديدا",
    "Name" : "اسم",
    "Public" : "للعامة",
    "Restricted" : "مقيدة",
    "Invisible" : "غير مرئية",
    "Delete" : "حذف ",
    "Reset" : "إعادة الضبط",
    "No files in here" : "لا يوجد ملفات هنا ",
    "No entries found in this folder" : "لا يوجد مدخلات في هذا المجلد ",
    "Size" : "حجم",
    "Modified" : "معدل",
    "Tagged files" : "الملفات الموسومة",
    "Select tags to filter by" : "حدد الوسوم للترشيح بواسطتها",
    "Please select tags to filter by" : "الرجاء تحديد الوسوم لترشيح بواسطتها",
    "No files found for the selected tags" : "لم يتم العثور على ملفات مع الوسوم المختارة"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
